@@ -1,11 +1,11 @@
 # ----------------------------------------------------------- class: Constants ----------------------------------------------------------- #
 
 class Constants:
-    CONFIG_FILE_NAME               = '.pypi_utils.json'
+    CONFIG_FILE_NAME               = '.kcliutils.json'
     GITIGNORE_FILE_NAME            = '.gitignore'
     DEMO_FILE_NAME                 = 'demo.py'
     README_FILE_NAME               = 'README.md'
-    LICENSE_FILE_NAME              = 'LICENSE.md'
+    LICENSE_FILE_NAME              = 'LICENSE'
     SETUP_FILE_NAME                = 'setup.py'
     INIT_PY_FILE_NAME              = '__init__.py'
     INSTALL_DEPENDENCIES_FILE_NAME = 'install_dependencies.sh'
@@ -13,4 +13,4 @@ class Constants:
     PYTHON_VERSIONS                = ['3.4', '3.5', '3.6', '3.7', '3.8', '3.9']
 
 
-# ---------------------------------------------------------------------------------------------------------------------------------------- #
+# ---------------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
