@@ -5,14 +5,14 @@ from typing import Optional, List
 import os, time
 
 # Pip
-from kcu import kpath, strio, sh
+from kcu import kpath, strio, sh, kjson
 from kdependencies import Dependencies, InstalledPackage
 
 # Local
 from .constants import Constants
 from .utils import Utils
 from .prompt import Prompt
-from .texts import new_api, new_class, new_enum, new_license, file, flow, gitignore, new_readme, updated_readme, new_setup, updated_setup, new_install_dependencies_file, current_version_number
+from .texts import new_api, new_class, new_json_class, new_enum, new_license, file, flow, gitignore, new_readme, updated_readme, new_setup, updated_setup, new_install_dependencies_file, current_version_number
 
 # ---------------------------------------------------------------------------------------------------------------------------------------- #
 
@@ -36,6 +36,8 @@ class Flows:
         if not os.path.exists(Utils.setup_file_path()):
             Utils.create_file(Utils.setup_file_path(), new_setup(
                 package_name=package_name,
+                author=config.default_author,
+                git_url=Utils.get_git_url(),
                 min_python_version=config.default_min_python_version,
                 max_python_version=config.default_max_python_version,
                 license_str='License :: OSI Approved :: MIT License'
@@ -47,6 +49,9 @@ class Flows:
         if not os.path.exists(Utils.gitignore_path()):
             cls.create_new_gitignore(open=False)
 
+        if not os.path.exists(Utils.license_path()):
+            Utils.create_file(Utils.license_path(), new_license(config.default_author))
+
         if not os.path.exists(Utils.demo_path()):
             Utils.create_file(Utils.demo_path())
 
@@ -94,7 +99,8 @@ class Flows:
 
         if reinstall:
             print('Reinstalling \'{}\''.format(current_package_name))
-            cls.reinstall(current_package_name, version=current_version_number(Utils.setup_file_path()), max_install_try_count=5)
+            cls.uninstall(current_package_name)
+            cls.install('.')
 
     @classmethod
     def publish_and_push(cls, message: Optional[str] = None, clean_lines: bool = True):
@@ -105,6 +111,22 @@ class Flows:
         print('Reinstalling \'{}\''.format(current_package_name))
         cls.reinstall(current_package_name, version=current_version_number(Utils.setup_file_path()), max_install_try_count=5)
 
+    @classmethod
+    def upgrade_push_install(cls, message: Optional[str] = None, clean_lines: bool = True, reinstall: bool = True):
+        Utils.ensure_and_get_path()
+        current_package_name = Utils.get_current_package_name()
+
+        print('Upgrading \'{}\''.format(current_package_name))
+        cls.upgrade(ensure_path=False, clean_lines=clean_lines)
+
+        if reinstall:
+            print('Reinstalling \'{}\''.format(current_package_name))
+
+            cls.uninstall(current_package_name)
+            cls.install('.')
+
+        cls.push(ensure_path=False, clean_lines=False)
+
     @classmethod
     def clean_lines(cls, ensure_path: bool = True):
         if ensure_path:
@@ -113,7 +135,7 @@ class Flows:
         for p in kpath.file_paths_from_folder(os.getcwd(), allowed_extensions=cls.__allowed_extesions()):
             with open(p, 'r') as f:
                 org_text = f.read()
-                text = '\n'.join([l.rstrip() for l in org_text.strip().split('\n')]) + '\n'
+                text = '\n'.join([l.rstrip() for l in org_text.strip().split('\n')]).strip()
 
             if org_text != text:
                 print('Cleaning: \'{}\''.format(p))
@@ -125,13 +147,14 @@ class Flows:
     # Git
 
     @classmethod
-    def push(cls, message: Optional[str] = None, ensure_path: bool = True, clean_lines: bool = True):
+    def push(cls, message: Optional[str] = None, ensure_path: bool = False, clean_lines: bool = True):
         if ensure_path:
             Utils.ensure_and_get_path()
 
         if clean_lines:
             cls.clean_lines(ensure_path=False)
 
+        sh.sh('set_git_user', debug=False)
         print(sh.sh('git add .', debug=True))
         print(sh.sh('git commit -a -m \'{}\''.format(message or Utils.get_config(True).default_commit_message), debug=True))
         print(sh.sh('git push', debug=True))
@@ -214,6 +237,16 @@ class Flows:
         if open:
             Utils.vscode_open(file_path)
 
+    @staticmethod
+    def new_class_from_json(json_path: str, name: Optional[str] = None, open: bool = True):
+        name = name or json_path.split(os.sep)[-1].split('.')[0]
+
+        _, file_path, _, _class = Utils.get_paths_name_class(name)
+        Utils.create_file(file_path, new_json_class(_class, kjson.load(json_path)))
+
+        if open:
+            Utils.vscode_open(file_path)
+
     @staticmethod
     def create_new_enum(name: str, open: bool = True):
         _, file_path, _, _class = Utils.get_paths_name_class(name)
@@ -289,4 +322,4 @@ class Flows:
         ]
 
 
-# ---------------------------------------------------------------------------------------------------------------------------------------- #
+# ---------------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
